==> qtjambi-webchannel-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWebChannel/QWebChannelAbstractTransport_shell.h <==
#ifndef QWEBCHANNELABSTRACTTRANSPORT_SHELL_H
#define QWEBCHANNELABSTRACTTRANSPORT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannel/qwebchannelabstracttransport.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qjsonobject.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QWebChannelAbstractTransport_shell : public QWebChannelAbstractTransport, public QtJambiShellInterface
{
public:
    QWebChannelAbstractTransport_shell(QObject* parent0 = nullptr);
    ~QWebChannelAbstractTransport_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QWebChannelAbstractTransport_mshell;
    friend class QWebChannelAbstractTransport_oshell;
};


class QWebChannelAbstractTransport_mshell : public QWebChannelAbstractTransport_shell
{
public:
    using QWebChannelAbstractTransport_shell::QWebChannelAbstractTransport_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWebChannelAbstractTransport_oshell : public QWebChannelAbstractTransport_mshell
{
public:
    using QWebChannelAbstractTransport_mshell::QWebChannelAbstractTransport_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sendMessage(const QJsonObject& message0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebChannelAbstractTransport_access : public QWebChannelAbstractTransport
{
    void __qt_sendMessage_cref_QJsonObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID message0);
};

#endif // QWEBCHANNELABSTRACTTRANSPORT_SHELL_H

==> qtjambi-webchannel-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiWebChannel/QWebChannelAbstractTransport_shell.h <==
#ifndef QWEBCHANNELABSTRACTTRANSPORT_SHELL_H
#define QWEBCHANNELABSTRACTTRANSPORT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannel/qwebchannelabstracttransport.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qjsonobject.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QWebChannelAbstractTransport_shell : public QWebChannelAbstractTransport, public QtJambiShellInterface
{
public:
    QWebChannelAbstractTransport_shell(QObject* parent0 = nullptr);
    ~QWebChannelAbstractTransport_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sendMessage(const QJsonObject& message0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebChannelAbstractTransport_access : public QWebChannelAbstractTransport
{
    void __qt_sendMessage_cref_QJsonObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID message0);
};

#endif // QWEBCHANNELABSTRACTTRANSPORT_SHELL_H
